searchData={"items":[{"type":"module","title":"Nf.App","doc":"Provides functions for generating app metadata.\n\nThis module includes functions to generate random app-related information, such as author names,\napp names, descriptions, versions, and licenses.","ref":"Nf.App.html"},{"type":"function","title":"Nf.App.author/0","doc":"Returns a random app author.\n\nThe author name is a randomly generated full name.","ref":"Nf.App.html#author/0"},{"type":"function","title":"Examples - Nf.App.author/0","doc":"iex> Nf.App.author()\n    \"José Valim\"","ref":"Nf.App.html#author/0-examples"},{"type":"function","title":"Nf.App.description/0","doc":"Returns a short app description.\n\nThe description provides a brief summary of the app.","ref":"Nf.App.html#description/0"},{"type":"function","title":"Examples - Nf.App.description/0","doc":"iex> Nf.App.description()\n    \"Elixir library for generating fake data in tests and development.\"","ref":"Nf.App.html#description/0-examples"},{"type":"function","title":"Nf.App.license/0","doc":"Returns a random open-source license.\n\nThe license is selected from a predefined list based on [ChooseALicense](https://choosealicense.com/appendix).","ref":"Nf.App.html#license/0"},{"type":"function","title":"Examples - Nf.App.license/0","doc":"iex> Nf.App.license()\n    \"MIT License\"","ref":"Nf.App.html#license/0-examples"},{"type":"function","title":"Nf.App.name/1","doc":"Returns a random app name.\n\nBy default, the app name is generated in a standard format. A different naming style can be\nspecified using the `:style` option.","ref":"Nf.App.html#name/1"},{"type":"function","title":"Options - Nf.App.name/1","doc":"The accepted options are:\n\n- `:style` - Specifies the style of the app name.\n\nThe values for `:style` can be:\n\n- `nil` (default) - Uses the standard format, e.g., `\"Neo Faker\"`.\n- `:camel_case` - Uses camel case, e.g., `\"neoFaker\"`.\n- `:pascal_case` - Uses Pascal case, e.g., `\"NeoFaker\"`.\n- `:dashed` - Uses a dashed style, e.g., `\"Neo-faker\"`.\n- `:single` - Uses a single-word format, e.g., `\"Faker\"`.","ref":"Nf.App.html#name/1-options"},{"type":"function","title":"Examples - Nf.App.name/1","doc":"iex> Nf.App.name()\n    \"Neo Faker\"\n\n    iex> Nf.App.name(style: :camel_case)\n    \"neoFaker\"\n\n    iex> Nf.App.name(style: :pascal_case)\n    \"NeoFaker\"\n\n    iex> Nf.App.name(style: :dashed)\n    \"Neo-faker\"\n\n    iex> Nf.App.name(style: :single)\n    \"Faker\"","ref":"Nf.App.html#name/1-examples"},{"type":"function","title":"Nf.App.semver/1","doc":"Returns a semantic version number.\n\nThe generated version number follows the Semantic Versioning (SemVer) standard. By default, it\ngenerates a core version (`MAJOR.MINOR.PATCH`). Additional versioning details can be specified\nusing the `:type` option.","ref":"Nf.App.html#semver/1"},{"type":"function","title":"Options - Nf.App.semver/1","doc":"The accepted options are:\n\n- `:type` - Specifies the type of version format.\n\nThe values for `:type` can be:\n\n- `nil` (default) - Uses core SemVer format, e.g., `\"1.2.3\"`.\n- `:pre_release` - Includes a pre-release label, e.g., `\"1.2.3-beta.1\"`.\n- `:build` - Includes a build metadata label, e.g., `\"1.2.3+20250325\"`.\n- `:pre_release_build` - Includes both pre-release and build metadata, e.g., `\"1.2.3-rc.1+20250325\"`.","ref":"Nf.App.html#semver/1-options"},{"type":"function","title":"Examples - Nf.App.semver/1","doc":"iex> Nf.App.semver()\n    \"1.2.3\"\n\n    iex> Nf.App.semver(:pre_release)\n    \"1.2.3-beta.1\"\n\n    iex> Nf.App.semver(:build)\n    \"1.2.3+20250325\"\n\n    iex> Nf.App.semver(:pre_release_build)\n    \"1.2.3-rc.1+20250325\"","ref":"Nf.App.html#semver/1-examples"},{"type":"function","title":"Nf.App.version/0","doc":"Returns a simple version number.\n\nThis version format follows `MAJOR.MINOR`.","ref":"Nf.App.html#version/0"},{"type":"function","title":"Examples - Nf.App.version/0","doc":"iex> Nf.App.version()\n    \"1.2\"","ref":"Nf.App.html#version/0-examples"},{"type":"module","title":"Nf.Blood","doc":"Provides functions for generating blood types.\n\nThis module includes functions to generate random blood type groups, blood types, and Rh factors.","ref":"Nf.Blood.html"},{"type":"function","title":"Nf.Blood.group/0","doc":"Returns a random blood type group.\n\nA blood type group consists of a blood type (`A`, `B`, `AB`, or `O`)\nand an Rh factor (`+` or `-`), forming a complete blood group.","ref":"Nf.Blood.html#group/0"},{"type":"function","title":"Examples - Nf.Blood.group/0","doc":"iex> Nf.Blood.group()\n  \"B+\"","ref":"Nf.Blood.html#group/0-examples"},{"type":"function","title":"Nf.Blood.rh_factor/0","doc":"Returns a random Rh factor.\n\nThe Rh factor is either `+` (positive) or `-` (negative).","ref":"Nf.Blood.html#rh_factor/0"},{"type":"function","title":"Examples - Nf.Blood.rh_factor/0","doc":"iex> Nf.Blood.rh_factor()\n    \"+\"","ref":"Nf.Blood.html#rh_factor/0-examples"},{"type":"function","title":"Nf.Blood.type/0","doc":"Returns a random blood type.\n\nA blood type is one of `A`, `B`, `AB`, or `O`, without the Rh factor.","ref":"Nf.Blood.html#type/0"},{"type":"function","title":"Examples - Nf.Blood.type/0","doc":"iex> Nf.Blood.type()\n  \"B\"","ref":"Nf.Blood.html#type/0-examples"},{"type":"module","title":"Nf.Boolean","doc":"Provides functions for generating boolean values.\n\nThis module offers a function to generate random boolean values with a configurable probability.","ref":"Nf.Boolean.html"},{"type":"function","title":"Nf.Boolean.boolean/1","doc":"Returns a random boolean value.\n\nBy default, the function returns `true` or `false` with equal probability (50% each).\nAn optional argument can be provided to adjust the chance of returning `true`.","ref":"Nf.Boolean.html#boolean/1"},{"type":"function","title":"Examples - Nf.Boolean.boolean/1","doc":"iex> Nf.Boolean.boolean()\n    false\n\n    iex> Nf.Boolean.boolean(75)\n    true","ref":"Nf.Boolean.html#boolean/1-examples"},{"type":"module","title":"Nf.Crypto","doc":"Provides functions for generating cryptographic hashes.","ref":"Nf.Crypto.html"},{"type":"module","title":"Options - Nf.Crypto","doc":"The accepted options are:\n\n  - `:case` - Specifies the character case of the output.\n\nThe values for `:case` can be:\n\n  - `:lower` (default) - Uses lowercase characters.\n  - `:upper` - Uses uppercase characters.","ref":"Nf.Crypto.html#module-options"},{"type":"function","title":"Nf.Crypto.md5/1","doc":"Generates a random MD5 hash.\n\nReturns a random MD5 hash string.\n\nSee the module documentation for available options.","ref":"Nf.Crypto.html#md5/1"},{"type":"function","title":"Examples - Nf.Crypto.md5/1","doc":"iex> Nf.Hash.md5()\n    \"e35cb102765cfc56df21ba4c16e6a636\"","ref":"Nf.Crypto.html#md5/1-examples"},{"type":"function","title":"Nf.Crypto.sha1/1","doc":"Generates a random SHA-1 hash.\n\nReturns a random SHA-1 hash string.\n\nSee the module documentation for available options.","ref":"Nf.Crypto.html#sha1/1"},{"type":"function","title":"Examples - Nf.Crypto.sha1/1","doc":"iex> Nf.Hash.sha1()\n    \"c8719790cdfff41c37c75e0c848d2b57535255aa\"","ref":"Nf.Crypto.html#sha1/1-examples"},{"type":"function","title":"Nf.Crypto.sha256/1","doc":"Generates a random SHA-256 hash.\n\nReturns a random SHA-256 hash string.\n\nSee the module documentation for available options.","ref":"Nf.Crypto.html#sha256/1"},{"type":"function","title":"Examples - Nf.Crypto.sha256/1","doc":"iex> Nf.Hash.sha256()\n    \"d0ff021e810fb8f3442a14393604b0661b02f0dfcb347d80c9580af3ab5e7e6c\"","ref":"Nf.Crypto.html#sha256/1-examples"},{"type":"module","title":"Nf.Gravatar","doc":"Provides functions for generating random Gravatar URLs.\n\nThis module is based on the [Gravatar API documentation](https://docs.gravatar.com/api/avatars/images).","ref":"Nf.Gravatar.html"},{"type":"function","title":"Nf.Gravatar.display/2","doc":"Generates a Gravatar URL from an email address.\n\nThe generated URL includes query parameters for image size and fallback options.\nIf no email address is provided, a random one is used.","ref":"Nf.Gravatar.html#display/2"},{"type":"function","title":"Options - Nf.Gravatar.display/2","doc":"The following options are available:\n\n- `:size` - Defines the image size.\n- `:fallback` - Specifies the default fallback image.\n\n### `:size`\n\nDefines the image size.\n\n- `nil` (default) - Uses 80px.\n- `integer` - The image size in pixels (valid range: `1` to `2048`).\n\n### `:fallback`\n\nSpecifies the default fallback image.\n\n- `nil` (default) - Uses `\"identicon\"`.\n- `:identicon` - Generates an \"identicon\".\n- `:monsterid` - Generates a \"monsterid\".\n- `:wavatar` - Generates a \"wavatar\".\n- `:robohash` - Generates a \"robohash\".","ref":"Nf.Gravatar.html#display/2-options"},{"type":"function","title":"Examples - Nf.Gravatar.display/2","doc":"iex> Nf.Gravatar.display()\n    \"https://gravatar.com/avatar/836f82db99121b3481011f16b49dfa5fbc714a0d1b1b9f784a1ebbbf5b39577f?d=identicon&s=80\"\n\n    iex> Nf.Gravatar.display(\"john.doe@example.com\")\n    \"https://gravatar.com/avatar/836f82db99121b3481011f16b49dfa5fbc714a0d1b1b9f784a1ebbbf5b39577f?d=identicon&s=80\"\n\n    iex> Nf.Gravatar.display(\"john.doe@example.com\", size: 100)\n    \"https://gravatar.com/avatar/836f82db99121b3481011f16b49dfa5fbc714a0d1b1b9f784a1ebbbf5b39577f?d=identicon&s=100\"\n\n    iex> Nf.Gravatar.display(\"john.doe@example.com\", fallback: \"monsterid\")\n    \"https://gravatar.com/avatar/836f82db99121b3481011f16b49dfa5fbc714a0d1b1b9f784a1ebbbf5b39577f?d=monsterid&s=80\"","ref":"Nf.Gravatar.html#display/2-examples"},{"type":"type","title":"Nf.Gravatar.email/0","doc":"Email address","ref":"Nf.Gravatar.html#t:email/0"},{"type":"module","title":"Nf.Helper","doc":"Provides utility functions commonly used across modules.","ref":"Nf.Helper.html"},{"type":"type","title":"Nf.Helper.exs_path/0","doc":"Path to the `priv/lib` directory","ref":"Nf.Helper.html#t:exs_path/0"},{"type":"function","title":"Nf.Helper.get_data_path/0","doc":"Returns the absolute path to the `lib/data/` directory.\n\nThis path is useful for loading dynamic files, such as `.exs` scripts.","ref":"Nf.Helper.html#get_data_path/0"},{"type":"function","title":"Nf.Helper.read_exs_file!/2","doc":"Reads an `.exs` script file from the `lib/data/` directory and returns its contents as a map.","ref":"Nf.Helper.html#read_exs_file!/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.0"}}